@@ -2,34 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalender",
-    "New event" : "Uus sündmus",
-    "Global" : "Üldine",
-    "None" : "Pole",
-    "Attendees" : "Osalejad",
-    "Reminders" : "Meelespead",
-    "Does not repeat" : "Ei kordu",
-    "Daily" : "Iga päev",
-    "Weekly" : "Iga nädal",
-    "Every Weekday" : "Igal nädalapäeval",
-    "Bi-weekly" : "Üle nädala",
-    "Monthly" : "Igal kuul",
-    "Yearly" : "Igal aastal",
-    "never" : "mitte kunagi",
-    "by occurances" : "toimumiskordade järgi",
-    "by date" : "kuupäeva järgi",
-    "by monthday" : "kuu päeva järgi",
-    "by weekday" : "nädalapäeva järgi",
-    "by events date" : "ürituste kuupäeva järgi",
-    "by yearday(s)" : "aasta päeva(de) järgi",
-    "by day and month" : "kuu ja päeva järgi",
-    "Monday" : "Esmaspäev",
-    "Tuesday" : "Teisipäev",
-    "Wednesday" : "Kolmapäev",
-    "Thursday" : "Neljapäev",
-    "Friday" : "Reede",
-    "Saturday" : "Laupäev",
-    "Sunday" : "Pühapäev",
-    "Other" : "Muu",
     "Individual" : "Individuaalne",
     "Group" : "Grupp",
     "Resource" : "Ressurss",
@@ -37,66 +9,96 @@ OC.L10N.register(
     "Unknown" : "Tundmatu",
     "Required" : "Kohustuslik",
     "Optional" : "Valikuline",
+    "Does not attend" : "Ei võta soa",
+    "New event" : "Uus sündmus",
+    "Attendees" : "Osalejad",
+    "Reminders" : "Meelespead",
+    "Repeating" : "Kordamine",
     "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
+    "Please add a title!" : "Palu lisa pealkiri!",
+    "Please select a calendar!" : "Palun vali kalender!",
+    "Global" : "Üldine",
+    "None" : "Pole",
+    "Every day" : "Iga päev",
+    "Every week" : "Iga nädal",
+    "Every month" : "Iga kuu",
+    "Every year" : "Iga aasta",
+    "never" : "mitte kunagi",
+    "after" : "pärast",
     "At time of event" : "Sündmuse aeg",
     "5 minutes before" : "5 minutit enne",
     "10 minutes before" : "10 minutit enne",
     "15 minutes before" : "15 minutit enne",
+    "30 minutes before" : "30 minutit enne",
     "1 hour before" : "1 tund enne",
     "2 hours before" : "2 tundi enne",
     "Custom" : "Kohandatud",
     "Audio" : "Helid",
     "E Mail" : "E-post",
+    "Pop up" : "Hüpikaken",
     "sec" : "sek",
     "min" : "min",
     "hours" : "tundi",
     "days" : "päeva",
     "week" : "nädal",
-    "Before" : "Enne",
-    "After" : "Pärast",
-    "Start" : "Start",
-    "End" : "Lõpp",
+    "before" : "enne",
+    "start" : "algus",
+    "end" : "lõpp",
+    "Successfully imported" : "Imporditud",
+    "Pop-up" : "Hüpikaken",
     "E-Mail" : "E-post",
     "{type} at {time}" : "{type} kell {time}",
     "{calendar} shared by {owner}" : "{calendar} jagas {owner}",
+    "Title of the Event" : "Sündmuse pealkiri",
+    "starts" : "algab",
+    "ends" : "lõpeb",
+    "All day Event" : "Kogu päeva sündmus",
+    "Location" : "Asukoht",
+    "Delete" : "Kustuta",
+    "Cancel" : "Loobu",
+    "More ..." : "Veel ...",
+    "Create" : "Lisa",
+    "Update" : "Uuenda",
+    "Close" : "Sulge",
+    "Description" : "Kirjeldus",
+    "Export" : "Ekspordi",
     "Day" : "Päev",
     "Week" : "Nädal",
     "Month" : "Kuu",
     "Today" : "Täna",
     "Share Calendar" : "Jaga kalendrit",
+    "More" : "Rohkem",
+    "Edit" : "Muuda",
+    "CalDAV" : "CalDAV",
     "group" : "grupp",
     "New Calendar" : "Uus kalender",
-    "Create" : "Lisa",
     "Subscriptions" : "Tellimused",
     "New Subscription" : "Uus tellimus",
     "Url" : "URL",
     "Edit event" : "Muuda sündmust",
     "Delete Event" : "Kustuta sündmus",
+    "Save Event" : "Salvesta sündmus",
     "Time" : "Aeg",
     "Type" : "Tüüp",
     "Relative" : "Suhteline",
     "Absolute" : "Absoluutne",
-    "Date" : "Kuupäev",
     "Repeat" : "Korda",
+    "times every" : "korda iga",
     "Add" : "Lisa",
-    "Title of the Event" : "Sündmuse pealkiri",
     "from" : "alates",
     "to" : "kuni",
-    "Location" : "Asukoht",
-    "ends" : "lõpeb",
-    "Delete" : "Kustuta",
-    "Cancel" : "Loobu",
-    "More ..." : "Veel ...",
-    "Update" : "Uuenda",
-    "Close" : "Sulge",
-    "Interval" : "Intervall",
-    "Description" : "Kirjeldus",
-    "Export" : "Ekspordi",
+    "Reset repeating rule" : "Nulli kordamise reegel",
+    "Repeat every ..." : "Korda iga ...",
+    "end repeat ..." : "lõpeta kordamine",
+    "times" : "korda",
     "Import Calendars" : "Impordi kalendreid",
+    "Import canceled" : "Importimine on tühistatud",
     "Analyzing calendar" : "Kalendri analüüsimine",
     "New calendar" : "Uus kalender",
+    "Import scheduled" : "Importimine on ajastatud",
     "Settings" : "Seaded",
     "Import calendar" : "Impordi kalender",
+    "No Calendars selected for import" : "Pole valitud kalendreid, mida importida",
     "Primary CalDAV address" : "Primaarne CalDAV aadress",
     "iOS/OS X CalDAV address" : "iOS/OS X CalDAV aadress"
 },
