@@ -2,34 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalenteri",
-    "New event" : "Uusi tapahtuma",
-    "None" : "Ei mitään",
-    "Attendees" : "Osallistujat",
-    "Reminders" : "Muistutukset",
-    "Does not repeat" : "Ei toistoa",
-    "Daily" : "Päivittäin",
-    "Weekly" : "Viikottain",
-    "Every Weekday" : "Arkipäivisin",
-    "Bi-weekly" : "Kahden viikon välein",
-    "Monthly" : "Kuukausittain",
-    "Yearly" : "Vuosittain",
-    "never" : "ei koskaan",
-    "by occurances" : "kertojen mukaan",
-    "by date" : "päivämäärän mukaan",
-    "by monthday" : "kuukaudenpäivän mukaan",
-    "by weekday" : "viikonpäivän mukaan",
-    "by events date" : "tapahtumien päivämäärän mukaan",
-    "by yearday(s)" : "vuoden päivän mukaan",
-    "by week no(s)" : "viikkonumeroiden mukaan",
-    "by day and month" : "päivän ja kuukauden mukaan",
-    "Monday" : "maanantai",
-    "Tuesday" : "tiistai",
-    "Wednesday" : "keskiviikko",
-    "Thursday" : "torstai",
-    "Friday" : "perjantai",
-    "Saturday" : "lauantai",
-    "Sunday" : "sunnuntai",
-    "Other" : "Muu",
     "Group" : "Ryhmä",
     "Resource" : "Resurssi",
     "Room" : "Huone",
@@ -37,9 +9,23 @@ OC.L10N.register(
     "Required" : "Vaadittu",
     "Optional" : "Valinnainen",
     "Does not attend" : "Ei osallistu",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Olet tuntemattomalla aikavyöhykkeellä ({tz}), palataan UTC-tilaan",
+    "Please create a calendar first." : "Luo ensin kalenteri.",
+    "New event" : "Uusi tapahtuma",
+    "Attendees" : "Osallistujat",
+    "Reminders" : "Muistutukset",
+    "Repeating" : "Toisto",
     "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
     "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
     "When shared hide this event" : "Jaettuna piilota tämä tapahtuma",
+    "Please add a title!" : "Lisää otsikko!",
+    "Please select a calendar!" : "Valitse kalenteri!",
+    "None" : "Ei mitään",
+    "Every day" : "Päivittäin",
+    "Every week" : "Viikottain",
+    "Every month" : "Kuukausittain",
+    "Every year" : "Vuosittain",
+    "never" : "ei koskaan",
     "At time of event" : "Tapahtuman aikaan",
     "5 minutes before" : "5 minuuttia ennen",
     "10 minutes before" : "10 minuuttia ennen",
@@ -56,10 +42,6 @@ OC.L10N.register(
     "hours" : "tuntia",
     "days" : "päivää",
     "week" : "viikko",
-    "Before" : "Ennen",
-    "After" : "Jälkeen",
-    "Start" : "Alku",
-    "End" : "Loppu",
     "Week {number} of {year}" : "Viikko {number} vuonna {year}",
     "Successfully imported" : "Tuotu onnistuneesti",
     "Partially imported, 1 failure" : "Tuotu osittain, 1 epäonnistui",
@@ -75,14 +57,30 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} tapahtuman päättyessä",
     "{type} at {time}" : "{type} ajankohtana {time}",
     "{calendar} shared by {owner}" : "{calendar} jakanut {owner}",
+    "Title of the Event" : "Tapahtuman otsikko",
+    "starts" : "alkaa",
+    "ends" : "päättyy",
+    "All day Event" : "Koko päivän tapahtuma",
+    "Location" : "Sijainti",
+    "Delete" : "Poista",
+    "Cancel" : "Peruuta",
+    "More ..." : "Lisää...",
+    "Create" : "Luo",
+    "Update" : "Päivitä",
+    "Close" : "Sulje",
+    "Description" : "Kuvaus",
+    "Export" : "Vie",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Ota yhteys ylläpitoon ja pyydä poistamaan käytöstä valinta \"asset-pipeline.enabled\" asetustiedostosta.",
     "Day" : "Päivä",
     "Week" : "Viikko",
     "Month" : "Kuukausi",
     "Today" : "Tänään",
     "Share Calendar" : "Jaa kalenteri",
+    "More" : "Lisää",
+    "Edit" : "Muokkaa",
+    "CalDAV" : "CalDAV",
     "group" : "ryhmä",
     "New Calendar" : "Uusi kalenteri",
-    "Create" : "Luo",
     "Subscriptions" : "Tilaukset",
     "New Subscription" : "Uusi tilaus",
     "Url" : "Osoite",
@@ -91,26 +89,15 @@ OC.L10N.register(
     "Save Event" : "Tallenna tapahtuma",
     "Time" : "Aika",
     "Type" : "Tyyppi",
-    "Date" : "Päivämäärä",
     "Repeat" : "Kertaa",
     "Add" : "Lisää",
     "E-Mail address of attendee" : "Osallistujan sähköpostiosoite",
     "Please add your email address in the personal settings in order to add attendees." : "Lisää sähköpostiosoitteesi henkilökohtaisiin asetuksiin, jotta voit lisätä osallistujia.",
-    "Title of the Event" : "Tapahtuman otsikko",
     "from" : "alkaen",
     "to" : "päättyen",
-    "All day Event" : "Koko päivän tapahtuma",
-    "Location" : "Sijainti",
-    "starts" : "alkaa",
-    "ends" : "päättyy",
-    "Delete" : "Poista",
-    "Cancel" : "Peruuta",
-    "More ..." : "Lisää...",
-    "Update" : "Päivitä",
-    "Close" : "Sulje",
-    "Interval" : "Aikaväli",
-    "Description" : "Kuvaus",
-    "Export" : "Vie",
+    "This event's repeating rule is not supported yet." : "Tämän tapahtuman toistuva sääntö ei ole vielä tuettu.",
+    "Support for advanced rules will be added with subsequent updates." : "Tuki kehittyneille säännöille lisätään myöhemmin julkaistavissa päivityksissä.",
+    "Reset repeating rule" : "Nollaa toistuva sääntö",
     "Import Calendars" : "Tuo kalentereita",
     "Import canceled" : "Tuonti peruttu",
     "Analyzing calendar" : "Analysoidaan kalenteria",
