@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "יומן",
-    "New event" : "אירוע חדש",
-    "Global" : "גלובלי",
-    "None" : "כלום",
-    "Attendees" : "משתתפים",
-    "Reminders" : "תזכורות",
-    "Does not repeat" : "ללא חזרה",
-    "Daily" : "יומי",
-    "Weekly" : "שבועי",
-    "Every Weekday" : "כל יום עבודה",
-    "Bi-weekly" : "דו-שבועי",
-    "Monthly" : "חודשי",
-    "Yearly" : "שנתי",
-    "never" : "לעולם לא",
-    "by occurances" : "על פי מופעים",
-    "by date" : "לפי תאריך",
-    "by monthday" : "לפי היום בחודש",
-    "by weekday" : "לפי היום בשבוע",
-    "by events date" : "לפי תאריכי האירועים",
-    "by yearday(s)" : "לפי ימים בשנה",
-    "by week no(s)" : "לפי מספרי שבוע(ות)",
-    "by day and month" : "לפי יום וחודש",
-    "Monday" : "יום שני",
-    "Tuesday" : "יום שלישי",
-    "Wednesday" : "יום רביעי",
-    "Thursday" : "יום חמישי",
-    "Friday" : "יום שישי",
-    "Saturday" : "שבת",
-    "Sunday" : "יום ראשון",
-    "Other" : "אחר",
     "Individual" : "פרטני",
     "Group" : "קבוצה",
     "Resource" : "משאב",
@@ -39,9 +10,23 @@ OC.L10N.register(
     "Required" : "נדרש",
     "Optional" : "אופציונלי",
     "Does not attend" : "לא משתתף",
+    "New event" : "אירוע חדש",
+    "Attendees" : "משתתפים",
+    "Reminders" : "תזכורות",
+    "Repeating" : "חוזר",
     "When shared show full event" : "כאשר משותף מציג אירוע מלא",
     "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
     "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
+    "Please add a title!" : "יש להוסיף כותרת!",
+    "Please select a calendar!" : "יש לבחור לוח שנה!",
+    "Global" : "גלובלי",
+    "None" : "כלום",
+    "Every day" : "כל יום",
+    "Every week" : "כל שבוע",
+    "Every month" : "כל חודש",
+    "Every year" : "כל שנה",
+    "never" : "לעולם לא",
+    "after" : "לאחר",
     "At time of event" : "בזמן אירוע",
     "5 minutes before" : "5 דקות לפני",
     "10 minutes before" : "10 דקות לפני",
@@ -58,10 +43,10 @@ OC.L10N.register(
     "hours" : "שעות",
     "days" : "ימים",
     "week" : "שבוע",
-    "Before" : "לפני",
-    "After" : "אחרי",
-    "Start" : "התחלה",
-    "End" : "סיום",
+    "before" : "לפני",
+    "start" : "התחלה",
+    "end" : "סוף",
+    "Editing reminders of uknown type not supported." : "עריכת תזכורות של סוגים לא ידועים אינה נתמכת.",
     "Week {number} of {year}" : "שבוע {number} מ- {year}",
     "Successfully imported" : "יובא בהצלחה",
     "Partially imported, 1 failure" : "יובא חלקית, 1 שגיאה",
@@ -77,14 +62,30 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} בסיום האירוע",
     "{type} at {time}" : "{type} בשעה {time}",
     "{calendar} shared by {owner}" : "{calendar} משותף על ידי {owner}",
+    "Title of the Event" : "כותרת האירוע",
+    "starts" : "מתחיל",
+    "ends" : "מסתיים",
+    "All day Event" : "אירוע יום מלא",
+    "Location" : "מיקום",
+    "Delete" : "מחיקה",
+    "Cancel" : "ביטול",
+    "More ..." : "עוד...",
+    "Create" : "יצירה",
+    "Update" : "עדכון",
+    "Close" : "סגירה",
+    "Description" : "תיאור",
+    "Export" : "ייצוא",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "בשל באג upstream, היומן לא יכול לספק תמיכה לתכונת asset pipeline.",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "יש ליצור קשר עם המנהל שלך לבקש לנטרל את אפשרות תצורה \"asset-pipeline.enabled\".",
     "Day" : "יום",
     "Week" : "שבוע",
     "Month" : "חודש",
     "Today" : "היום",
     "Share Calendar" : "שיתוף לוח שנה",
+    "More" : "יותר",
+    "Edit" : "עריכה",
     "group" : "קבוצה",
     "New Calendar" : "לוח שנה חדש",
-    "Create" : "יצירה",
     "Subscriptions" : "מנויים",
     "New Subscription" : "מנוי חדש",
     "Url" : "נתיב אינטרנט",
@@ -95,27 +96,19 @@ OC.L10N.register(
     "Type" : "סוג",
     "Relative" : "יחסי",
     "Absolute" : "מוחלט",
-    "Date" : "תאריך",
     "Repeat" : "חזרה",
     "times every" : "פעמים כל",
     "Add" : "הוספה",
     "E-Mail address of attendee" : "כתובת דואר אלקטרוני של משתתף",
     "Please add your email address in the personal settings in order to add attendees." : "יש להזין את כתובת הדואר האלקטרוני שלך בהגדרות האישיות בכדי להוסיף מוזמנים.",
-    "Title of the Event" : "כותרת האירוע",
     "from" : "מאת",
     "to" : "אל",
-    "All day Event" : "אירוע יום מלא",
-    "Location" : "מיקום",
-    "starts" : "מתחיל",
-    "ends" : "מסתיים",
-    "Delete" : "מחיקה",
-    "Cancel" : "ביטול",
-    "More ..." : "עוד...",
-    "Update" : "עדכון",
-    "Close" : "סגירה",
-    "Interval" : "משך",
-    "Description" : "תיאור",
-    "Export" : "ייצוא",
+    "This event's repeating rule is not supported yet." : "כלל חזרה לאירוע זה עדיין אינו נתמך.",
+    "Support for advanced rules will be added with subsequent updates." : "תמיכת כללים מתקדמים תתווסף עם עדכונים מאוחרים יותר.",
+    "Reset repeating rule" : "איפוס כלל חזרה",
+    "Repeat every ..." : "חזרה כל...",
+    "end repeat ..." : "סיום חזרה...",
+    "times" : "פעמים",
     "Import Calendars" : "יבוא יומנים",
     "Import canceled" : "יבוא בוטל",
     "Analyzing calendar" : "מנתח יומן",
