@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalender",
-    "New event" : "Ny hendelse",
-    "Global" : "Global",
-    "None" : "Ingen",
-    "Attendees" : "Deltakere",
-    "Reminders" : "Varsler",
-    "Does not repeat" : "Gjentas ikke",
-    "Daily" : "Daglig",
-    "Weekly" : "Ukentlig",
-    "Every Weekday" : "Hver ukedag",
-    "Bi-weekly" : "Annenhver uke",
-    "Monthly" : "Månedlig",
-    "Yearly" : "Årlig",
-    "never" : "aldri",
-    "by occurances" : "etter hyppighet",
-    "by date" : "etter dato",
-    "by monthday" : "etter dag i måned",
-    "by weekday" : "etter ukedag",
-    "by events date" : "etter hendelsenes dato",
-    "by yearday(s)" : "etter dag i året",
-    "by week no(s)" : "etter ukenummer",
-    "by day and month" : "etter dag og måned",
-    "Monday" : "Mandag",
-    "Tuesday" : "Tirsdag",
-    "Wednesday" : "Onsdag",
-    "Thursday" : "Torsdag",
-    "Friday" : "Fredag",
-    "Saturday" : "Lørdag",
-    "Sunday" : "Søndag",
-    "Other" : "Annet",
     "Individual" : "Individuel",
     "Group" : "Gruppe",
     "Resource" : "Ressurs",
@@ -39,9 +10,23 @@ OC.L10N.register(
     "Required" : "Påkrevet",
     "Optional" : "Valgfri",
     "Does not attend" : "Deltar ikke",
+    "New event" : "Ny hendelse",
+    "Attendees" : "Deltakere",
+    "Reminders" : "Varsler",
+    "Repeating" : "Gjentas",
     "When shared show full event" : "Vis hele hendelsen når delt",
     "When shared show only busy" : "Vis kun opptatt når delt",
     "When shared hide this event" : "Skjul denne hendelsen når delt",
+    "Please add a title!" : "Vennligst lag en tittel!",
+    "Please select a calendar!" : "Vennligst velg en kalender!",
+    "Global" : "Global",
+    "None" : "Ingen",
+    "Every day" : "Hver dag",
+    "Every week" : "Hver uke",
+    "Every month" : "Hver måned",
+    "Every year" : "Hvert år",
+    "never" : "aldri",
+    "after" : "etter",
     "At time of event" : "Ved tiden for hendelsen",
     "5 minutes before" : "5 minutter før",
     "10 minutes before" : "10 minutter før",
@@ -58,10 +43,6 @@ OC.L10N.register(
     "hours" : "timer",
     "days" : "dager",
     "week" : "uke",
-    "Before" : "Før",
-    "After" : "Etter",
-    "Start" : "Start",
-    "End" : "Slutt",
     "Week {number} of {year}" : "Uke {number} {year}",
     "Successfully imported" : "Vellykket importert",
     "Partially imported, 1 failure" : "Delvis importert, 1 feil",
@@ -77,14 +58,30 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} ved hendelsens slutt",
     "{type} at {time}" : "{type} {time}",
     "{calendar} shared by {owner}" : "{calendar} delt av {owner}",
+    "Title of the Event" : "Tittel for hendelsen",
+    "starts" : "starter",
+    "ends" : "slutter",
+    "All day Event" : "Heldagshendelse",
+    "Location" : "Sted",
+    "Delete" : "Slett",
+    "Cancel" : "Avbryt",
+    "More ..." : "Mer ...",
+    "Create" : "Opprett",
+    "Update" : "Oppdater",
+    "Close" : "Lukk",
+    "Description" : "Beskrivelse",
+    "Export" : "Eksporter",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Pga. en feil oppstrøms, støtter kalenderen for tiden ikke \"asset pipeline\".",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontakt administratoren og be dem deaktivere valget \"asset-pipeline.enabled\" i konfigurasjonen.",
     "Day" : "Dag",
     "Week" : "Uke",
     "Month" : "Måned",
     "Today" : "I dag",
     "Share Calendar" : "Del kalender",
+    "More" : "Mer",
+    "Edit" : "Endre",
     "group" : "gruppe",
     "New Calendar" : "Ny kalender",
-    "Create" : "Opprett",
     "Subscriptions" : "Abonnement",
     "New Subscription" : "Nytt abonnement",
     "Url" : "Url",
@@ -95,26 +92,19 @@ OC.L10N.register(
     "Type" : "Type",
     "Relative" : "Relativ",
     "Absolute" : "Absolutt",
-    "Date" : "Dato",
     "Repeat" : "Gjenta",
     "times every" : "ganger hver",
     "Add" : "Legg til",
+    "E-Mail address of attendee" : "E-postadresse for deltaker",
     "Please add your email address in the personal settings in order to add attendees." : "Vennligst legg inn epost-adressen din i personlige innstillinger for å kunne legge til deltakere.",
-    "Title of the Event" : "Tittel for hendelsen",
     "from" : "fra",
     "to" : "til",
-    "All day Event" : "Heldagshendelse",
-    "Location" : "Sted",
-    "starts" : "starter",
-    "ends" : "slutter",
-    "Delete" : "Slett",
-    "Cancel" : "Avbryt",
-    "More ..." : "Mer ...",
-    "Update" : "Oppdater",
-    "Close" : "Lukk",
-    "Interval" : "Intervall",
-    "Description" : "Beskrivelse",
-    "Export" : "Eksporter",
+    "This event's repeating rule is not supported yet." : "Hendelsens regel for gjentagelse støttes ikke ennå.",
+    "Support for advanced rules will be added with subsequent updates." : "Støtte for avanserte regler blir lagt til i senere oppdateringer.",
+    "Reset repeating rule" : "Nullstill gjentaksregel",
+    "Repeat every ..." : "Gjenta hver ...",
+    "end repeat ..." : "avslutt gjentak ...",
+    "times" : "ganger",
     "Import Calendars" : "Importerer kalendre",
     "Import canceled" : "Import avbrutt",
     "Analyzing calendar" : "Analyserer kalender",
