@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendário",
-    "New event" : "Novo evento",
-    "Global" : "Global",
-    "None" : "Nenhum",
-    "Attendees" : "Participantes",
-    "Reminders" : "Lembretes",
-    "Does not repeat" : "Não repetir",
-    "Daily" : "Diário",
-    "Weekly" : "Semanal",
-    "Every Weekday" : "Todo dia da semana",
-    "Bi-weekly" : "Quinzenal",
-    "Monthly" : "Mensal",
-    "Yearly" : "Anual",
-    "never" : "nunca",
-    "by occurances" : "por ocorrências",
-    "by date" : "por data",
-    "by monthday" : "por dia do mês",
-    "by weekday" : "por dia da semana",
-    "by events date" : "eventos por data",
-    "by yearday(s)" : "por dia(s) do ano",
-    "by week no(s)" : "por semana no(s)",
-    "by day and month" : "por dia e mês",
-    "Monday" : "Segunda-feira",
-    "Tuesday" : "Terça-feira",
-    "Wednesday" : "Quarta-feira",
-    "Thursday" : "Quinta-feira",
-    "Friday" : "Sexta-feira",
-    "Saturday" : "Sábado",
-    "Sunday" : "Domingo",
-    "Other" : "Outro",
     "Individual" : "Individual",
     "Group" : "Grupo",
     "Resource" : "Recurso",
@@ -39,9 +10,25 @@ OC.L10N.register(
     "Required" : "Requerido",
     "Optional" : "Opcional",
     "Does not attend" : "Não comparecer",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Você está em um fuso horário desconhecido ({tz}), caindo de volta para UTC",
+    "Please create a calendar first." : "Por favor crie um calendário primeiro.",
+    "New event" : "Novo evento",
+    "Attendees" : "Participantes",
+    "Reminders" : "Lembretes",
+    "Repeating" : "Repetindo",
     "When shared show full event" : "Quando compartilhado mostrar evento completo",
     "When shared show only busy" : "Quando compartilhado mostrar apenas ocupado",
     "When shared hide this event" : "Quando compartilhado esconder este evento",
+    "Please add a title!" : "Por favor adicione um título!",
+    "Please select a calendar!" : "Por favor selecione um calendário!",
+    "Global" : "Global",
+    "None" : "Nenhum",
+    "Every day" : "Todos os dias",
+    "Every week" : "Toda semana",
+    "Every month" : "Todo mês",
+    "Every year" : "Todo ano",
+    "never" : "nunca",
+    "after" : "após",
     "At time of event" : "No momento do evento",
     "5 minutes before" : "5 minutos antes",
     "10 minutes before" : "10 minutos antes",
@@ -58,10 +45,10 @@ OC.L10N.register(
     "hours" : "horas",
     "days" : "dias",
     "week" : "semana",
-    "Before" : "Antes",
-    "After" : "Depois",
-    "Start" : "Iniciar",
-    "End" : "Final",
+    "before" : "antes",
+    "start" : "início",
+    "end" : "fim",
+    "Editing reminders of uknown type not supported." : "Não é possível editar lembretes de tipos desconhecidos.",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Successfully imported" : "Importada com sucesso",
     "Partially imported, 1 failure" : "Parcialmente importada, 1 falha",
@@ -77,14 +64,31 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} no final do evento",
     "{type} at {time}" : "{type} em {time}",
     "{calendar} shared by {owner}" : "{calendar} compartilhado por {owner}",
+    "Title of the Event" : "Título do evento",
+    "starts" : "Inícios",
+    "ends" : "Finais",
+    "All day Event" : "Evento todo o dia",
+    "Location" : "Localização",
+    "Delete" : "Excluir",
+    "Cancel" : "Cancelar",
+    "More ..." : "Mais ...",
+    "Create" : "Criar",
+    "Update" : "Atualizar",
+    "Close" : "Fechar",
+    "Description" : "Descrição",
+    "Export" : "Exportar",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Devido a um bug a montante, o calendário não é atualmente capaz de fornecer suporte para o recurso de pipeline ativo.",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor entre em contato com o administrador e pedir-lhes para desativar a opção de configuração \"asset-pipeline.enabled\".",
     "Day" : "Dia",
     "Week" : "Semana",
     "Month" : "Mês",
     "Today" : "Hoje",
     "Share Calendar" : "Compartilhar Calendário",
+    "More" : "Mais",
+    "Edit" : "Editar",
+    "CalDAV" : "CalDAV",
     "group" : "grupo",
     "New Calendar" : "Novo Calendário",
-    "Create" : "Criar",
     "Subscriptions" : "Inscrições",
     "New Subscription" : "Nova Subscrição",
     "Url" : "Url",
@@ -95,26 +99,19 @@ OC.L10N.register(
     "Type" : "Digite",
     "Relative" : "Relativo",
     "Absolute" : "Absoluto",
-    "Date" : "Data",
     "Repeat" : "Repetir",
     "times every" : "vezes sempre",
     "Add" : "Adicionar",
+    "E-Mail address of attendee" : "Endereço de email do participante",
     "Please add your email address in the personal settings in order to add attendees." : "Por favor, adicione seu endereço de email nas configurações pessoais, a fim de adicionar participantes.",
-    "Title of the Event" : "Título do evento",
     "from" : "de",
     "to" : "para",
-    "All day Event" : "Evento todo o dia",
-    "Location" : "Localização",
-    "starts" : "Inícios",
-    "ends" : "Finais",
-    "Delete" : "Excluir",
-    "Cancel" : "Cancelar",
-    "More ..." : "Mais ...",
-    "Update" : "Atualizar",
-    "Close" : "Fechar",
-    "Interval" : "Intervalo",
-    "Description" : "Descrição",
-    "Export" : "Exportar",
+    "This event's repeating rule is not supported yet." : "Regra de repetição de evento ainda não é suportada.",
+    "Support for advanced rules will be added with subsequent updates." : "Suporte para regras avançadas serão adicionados com atualizações subsequentes.",
+    "Reset repeating rule" : "Reiniciar regra de repetição",
+    "Repeat every ..." : "Repetir a cada ...",
+    "end repeat ..." : "fim da repetição ...",
+    "times" : "vezes",
     "Import Calendars" : "Importar Calendários",
     "Import canceled" : "Importação cancelada",
     "Analyzing calendar" : "Analisando calendário",
