@@ -2,35 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalendar",
-    "New event" : "Veprimtari e re",
-    "Global" : "Globale",
-    "None" : "Asnjë",
-    "Attendees" : "Pjesëmarrës",
-    "Reminders" : "Kujtues",
-    "Does not repeat" : "Mos e përsërit",
-    "Daily" : "Përditë",
-    "Weekly" : "Çdo javë",
-    "Every Weekday" : "Çdo ditë jave",
-    "Bi-weekly" : "Çdo dy javë",
-    "Monthly" : "Çdo muaj",
-    "Yearly" : "Çdo vit",
-    "never" : "kurrë",
-    "by occurances" : "sipas hasjesh",
-    "by date" : "sipas datës",
-    "by monthday" : "sipas ditës së muajit",
-    "by weekday" : "sipas ditës së javës",
-    "by events date" : "sipas datash veprimtarie",
-    "by yearday(s)" : "sipas ditëve të vitit",
-    "by week no(s)" : "sipas javës no(s)",
-    "by day and month" : "sipas ditës dhe muajit",
-    "Monday" : "E hënë",
-    "Tuesday" : "E martë",
-    "Wednesday" : "E mërkurë",
-    "Thursday" : "E enjte",
-    "Friday" : "E premte",
-    "Saturday" : "E shtunë",
-    "Sunday" : "E dielë",
-    "Other" : "Tjetër",
     "Individual" : "Individual",
     "Group" : "Grup",
     "Resource" : "Burim",
@@ -39,9 +10,25 @@ OC.L10N.register(
     "Required" : "E domosdoshme",
     "Optional" : "Në dëshirë",
     "Does not attend" : "Nuk merr pjesë",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Gjendeni një zonë kohore të panjohur ({tz}), po përdoret parazgjedhja UTC",
+    "Please create a calendar first." : "Ju lutemi, së pari krijoni një kalendar.",
+    "New event" : "Veprimtari e re",
+    "Attendees" : "Pjesëmarrës",
+    "Reminders" : "Kujtues",
+    "Repeating" : "Përsëritëse",
     "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
     "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
     "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
+    "Please add a title!" : "Ju lutemi, shtoni një titull!",
+    "Please select a calendar!" : "Ju lutemi, përzgjidhni një kalendar",
+    "Global" : "Globale",
+    "None" : "Asnjë",
+    "Every day" : "Çdo ditë",
+    "Every week" : "Çdo javë",
+    "Every month" : "Çdo muaj",
+    "Every year" : "Çdo vit",
+    "never" : "kurrë",
+    "after" : "pas",
     "At time of event" : "Në kohën e veprimtarisë",
     "5 minutes before" : "5 minuta para",
     "10 minutes before" : "10 minuta para",
@@ -58,10 +45,10 @@ OC.L10N.register(
     "hours" : "orë",
     "days" : "ditë",
     "week" : "javë",
-    "Before" : "Para",
-    "After" : "Pas",
-    "Start" : "Fillim",
-    "End" : "Fund",
+    "before" : "përpara",
+    "start" : "fillim",
+    "end" : "mbarim",
+    "Editing reminders of uknown type not supported." : "Nuk mbulohet përpunimi i kujtuesve të një lloji të panjohur.",
     "Week {number} of {year}" : "Java e {number} e {year}",
     "Successfully imported" : "U importua me sukses",
     "Partially imported, 1 failure" : "Importuar pjesërisht, 1 dështim",
@@ -77,14 +64,31 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} në fund të veprimtarisë",
     "{type} at {time}" : "{type} në {time}",
     "{calendar} shared by {owner}" : "{calendar} ndarë nga {owner}",
+    "Title of the Event" : "Titulli i Veprimtarisë",
+    "starts" : "fillon",
+    "ends" : "mbaron",
+    "All day Event" : "Veprimtari Gjithëditore",
+    "Location" : "Vendndodhje",
+    "Delete" : "Fshije",
+    "Cancel" : "Anuloje",
+    "More ..." : "Më tepër …",
+    "Create" : "Krijoje",
+    "Update" : "Përditësoje",
+    "Close" : "Mbylle",
+    "Description" : "Përshkrim",
+    "Export" : "Eksportoji",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Për shkak të një të mete në degën kryesore, kalendari, hëpërhë, s’është në gjendje të ofrojë mbulim të veçorinë \"asset pipeline\".",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Ju lutemi, lidhuni me përgjegjësin tuaj dhe kërkojini të çaktivizojë mundësinë \"asset-pipeline.enabled\" te formësimet.",
     "Day" : "Ditë",
     "Week" : "Javë",
     "Month" : "Muaj",
     "Today" : "Sot",
     "Share Calendar" : "Ndani Kalendar",
+    "More" : "Më tepër",
+    "Edit" : "Përpunoni",
+    "CalDAV" : "CalDAV",
     "group" : "grup",
     "New Calendar" : "Kalendar i ri",
-    "Create" : "Krijoje",
     "Subscriptions" : "Pajtime",
     "New Subscription" : "Pajtim i Ri",
     "Url" : "URL",
@@ -95,27 +99,19 @@ OC.L10N.register(
     "Type" : "Lloj",
     "Relative" : "Relative",
     "Absolute" : "Absolute",
-    "Date" : "Datë",
     "Repeat" : "Përsërite",
     "times every" : "herë çdo",
     "Add" : "Shtoje",
     "E-Mail address of attendee" : "Adresa email e pjesëmarrësit",
     "Please add your email address in the personal settings in order to add attendees." : "Që të shtoni pjesëmarrës, ju lutemi, shtoni adresën tuaj email te rregullimet personale.",
-    "Title of the Event" : "Titulli i Veprimtarisë",
     "from" : "nga",
     "to" : "për",
-    "All day Event" : "Veprimtari Gjithëditore",
-    "Location" : "Vendndodhje",
-    "starts" : "fillon",
-    "ends" : "mbaron",
-    "Delete" : "Fshije",
-    "Cancel" : "Anuloje",
-    "More ..." : "Më tepër …",
-    "Update" : "Përditësoje",
-    "Close" : "Mbylle",
-    "Interval" : "Interval",
-    "Description" : "Përshkrim",
-    "Export" : "Eksportoji",
+    "This event's repeating rule is not supported yet." : "Ky rregull përsëritjesh veprimtarie nuk mbulohet ende.",
+    "Support for advanced rules will be added with subsequent updates." : "Mbulimi i rregullave të thelluara do të shtohet në përditësimet e ardhshme.",
+    "Reset repeating rule" : "Ricaktoni rregull përsëritje",
+    "Repeat every ..." : "Përsërite çdo …",
+    "end repeat ..." : "përfundoje përsëritjen më …",
+    "times" : "herë",
     "Import Calendars" : "Importoni Kalendarë",
     "Import canceled" : "Importimi u anulua",
     "Analyzing calendar" : "Analizim kalendari",
