@@ -2,13 +2,6 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "ปฏิทิน",
-    "New event" : "เหตุการณ์ใหม่",
-    "Global" : "ทั่วไป",
-    "None" : "ไม่มี",
-    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
-    "Repeating" : "ทำซ้ำ",
-    "Custom" : "กำหนดเอง",
-    "never" : "ไม่ต้องเลย",
     "Individual" : "ของแต่ละบุคคล",
     "Group" : "กลุ่ม",
     "Resource" : "ทรัพยากร",
@@ -17,6 +10,25 @@ OC.L10N.register(
     "Required" : "ที่จำเป็น",
     "Optional" : "ตัวเลือก",
     "Does not attend" : "ไม่ได้เข้าร่วม",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "คุณอยู่ในเขตเวลาที่ไม่รู้จัก ({tz}), กำลงกลับไปสู่ UTC",
+    "Please create a calendar first." : "กรุณาสร้างปฏิทินก่อน",
+    "New event" : "เหตุการณ์ใหม่",
+    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
+    "Reminders" : "การแจ้งเตือน",
+    "Repeating" : "ทำซ้ำ",
+    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมทั้งหมด",
+    "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
+    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้",
+    "Please add a title!" : "กรุณาเพิ่มหัวข้อ!",
+    "Please select a calendar!" : "กรุณาเลือกปฏิทิน!",
+    "Global" : "ทั่วไป",
+    "None" : "ไม่มี",
+    "Every day" : "ทุกวัน",
+    "Every week" : "ทุกสัปดาห์",
+    "Every month" : "ทุกเดือน",
+    "Every year" : "ทุกปี",
+    "never" : "ไม่ต้องเลย",
+    "after" : "หลัง",
     "At time of event" : "ในช่วงเวลาของเหตุการณ์",
     "5 minutes before" : "5 นาทีก่อนหน้านั้น",
     "10 minutes before" : "10 นาทีก่อนหน้านั้น",
@@ -24,6 +36,7 @@ OC.L10N.register(
     "30 minutes before" : "30 นาทีก่อนหน้านั้น",
     "1 hour before" : "1 ชั่วโมงก่อนหน้านั้น",
     "2 hours before" : "2 ชั่วโมงก่อนหน้านั้น",
+    "Custom" : "กำหนดเอง",
     "Audio" : "เสียง",
     "E Mail" : "อีเมล",
     "Pop up" : "ป๊อปอัพ",
@@ -32,10 +45,10 @@ OC.L10N.register(
     "hours" : "ชั่วโมง",
     "days" : "วัน",
     "week" : "สัปดาห์",
-    "Before" : "ก่อน",
-    "After" : "หลัง",
-    "Start" : "เริ่มต้น",
-    "End" : "สิ้นสุด",
+    "before" : "ก่อน",
+    "start" : "เริ่ม",
+    "end" : "จบ",
+    "Editing reminders of uknown type not supported." : "การแก้ไขการแจ้งเตือนประเภทที่ไม่รู้จักไม่ได้รับการสนับสนุน",
     "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
     "Successfully imported" : "นำเข้าสำเร็จ",
     "Partially imported, 1 failure" : "นำเข้าได้แค่บางส่วน ล้มเหลวไปแล้ว 1 ",
@@ -49,14 +62,34 @@ OC.L10N.register(
     "{type} {time} after the event ends" : "{type} {time} หลังจากที่เหตุการณ์จบลง",
     "{type} at the event's start" : "{type} ในช่วงที่เหตุการณ์เริ่มต้น",
     "{type} at the event's end" : "{type} ในช่วงที่เหตุการณ์จบลง",
+    "{type} at {time}" : "{type} ตอน {time}",
+    "{calendar} shared by {owner}" : "{calendar} ถูกแชร์โดย {owner}",
+    "Title of the Event" : "ชื่อของกิจกรรม",
+    "starts" : "เริ่ม",
+    "ends" : "จบ",
+    "All day Event" : "เหตุการณ์ตลอดทั้งวัน",
+    "Location" : "ตำแหน่งที่อยู่",
+    "Delete" : "ลบ",
+    "Cancel" : "ยกเลิก",
+    "More ..." : "เพิ่มเติม ...",
+    "Create" : "สร้าง",
+    "Update" : "อัพเดท",
+    "Close" : "ปิด",
+    "Description" : "รายละเอียด",
+    "Export" : "ส่งออก",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "เนื่องจากข้อผิดพลาดจากต้นทาง ปัจจุบันปฏิทินยังไม่ให้การสนับสนุนสำหรับคุณลักษณะ asset pipeline",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "กรุณาติดต่อผู้ดูแลระบบของคุณและขอให้ปิดการใช้งานการตั้งค่าตัวเลือก \"asset-pipeline.enabled\"",
     "Day" : "วัน",
     "Week" : "สัปดาห์",
     "Month" : "เดือน",
     "Today" : "วันนี้",
     "Share Calendar" : "เปิดแชร์ปฏิทิน",
+    "More" : "เพิ่มเติม",
+    "Edit" : "แก้ไข",
+    "CalDAV" : "CalDAV",
     "group" : "กลุ่มผู้ใช้งาน",
     "New Calendar" : "สร้างปฏิทินใหม่",
-    "Create" : "สร้าง",
+    "Subscriptions" : "สมัครสมาชิก",
     "New Subscription" : "สมัครสมาชิกใหม่",
     "Url" : "Url",
     "Edit event" : "แก้ไขกิจกรรม",
@@ -69,18 +102,18 @@ OC.L10N.register(
     "Repeat" : "ทำซ้ำ",
     "times every" : "ทุกครั้ง",
     "Add" : "เพิ่ม",
-    "Title of the Event" : "ชื่อของกิจกรรม",
+    "E-Mail address of attendee" : "ที่อยู่อีเมลของผู้เข้าร่วมประชุม",
+    "Please add your email address in the personal settings in order to add attendees." : "กรุณาเพิ่มที่อยู่อีเมลของคุณในการตั้งค่าส่วนบุคคลเพื่อเพิ่มผู้เข้าร่วมประชุม",
     "from" : "จาก",
     "to" : "ถึง",
-    "All day Event" : "เหตุการณ์ตลอดทั้งวัน",
-    "Location" : "ตำแหน่งที่อยู่",
-    "Delete" : "ลบ",
-    "Cancel" : "ยกเลิก",
-    "Update" : "อัพเดท",
-    "Close" : "ปิด",
-    "Description" : "รายละเอียด",
-    "Export" : "ส่งออก",
+    "This event's repeating rule is not supported yet." : "กฎการทำซ้ำของเหตุการณ์นี้ยังไม่ได้รับการสนับสนุน",
+    "Support for advanced rules will be added with subsequent updates." : "การสนับสนุนสำหรับกฎขั้นสูงจะถูกเพิ่มในภายหลังที่มีการปรับปรุง",
+    "Reset repeating rule" : "รีเซ็ตกฎการทำซ้ำ",
+    "Repeat every ..." : "ทำซ้ำตลอด ...",
+    "end repeat ..." : "ยกเลิกการทำซ้ำ ...",
+    "times" : "ครั้ง",
     "Import Calendars" : "นำเข้าปฏิทิน",
+    "Import canceled" : "การนำเข้าถูกยกเลิก",
     "Analyzing calendar" : "วิเคราะห์ปฏิทิน",
     "The file contains objects incompatible with the selected calendar" : "ไฟล์ประกอบด้วยวัตถุเข้ากันไม่ได้กับปฏิทินที่เลือก",
     "New calendar" : "สร้างปฏิทินใหม่",
