@@ -2,43 +2,31 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Takvim",
-    "None" : "Hiçbiri",
-    "Attendees" : "Katılanlar",
-    "Does not repeat" : "Tekrar etmiyor",
-    "Daily" : "Her gün",
-    "Weekly" : "Her hafta",
-    "Every Weekday" : "Hafta içi her gün",
-    "Bi-weekly" : "İki haftada bir",
-    "Monthly" : "Her ay",
-    "Yearly" : "Her yıl",
-    "never" : "hiçbir zaman",
-    "by occurances" : "sıklığa göre",
-    "by date" : "tarihe göre",
-    "by monthday" : "ay günlerine göre",
-    "by weekday" : "hafta günlerine göre",
-    "by events date" : "etkinlik tarihine göre",
-    "by yearday(s)" : "yıl günlerine göre",
-    "by week no(s)" : "hafta sayılarına göre",
-    "by day and month" : "gün ve aya göre",
-    "Monday" : "Pazartesi",
-    "Tuesday" : "Salı",
-    "Wednesday" : "Çarşamba",
-    "Thursday" : "Perşembe",
-    "Friday" : "Cuma",
-    "Saturday" : "Cumartesi",
-    "Sunday" : "Pazar",
-    "Other" : "Diğer",
     "Individual" : "Bireysel",
     "Group" : "Grup",
     "Resource" : "Kaynak",
     "Room" : "Oda",
     "Unknown" : "Bilinmeyen",
     "Required" : "Gerekli",
-    "Optional" : "Opsiyonel",
+    "Optional" : "İsteğe Bağlı",
     "Does not attend" : "Katılmıyor",
+    "New event" : "Yeni etkinli",
+    "Attendees" : "Katılanlar",
+    "Reminders" : "Hatırlatıcılar",
+    "Repeating" : "Tekrarlama",
     "When shared show full event" : "Paylaşıldığında etkinliği göster",
     "When shared show only busy" : "Paylaşıldğında sadece meşgulleri göster",
     "When shared hide this event" : "Paylaşıldığında bu etkinliği gizle",
+    "Please add a title!" : "Lütfen bir başlık ekleyin!",
+    "Please select a calendar!" : "Lütfen bir takvim seçin!",
+    "Global" : "Evrensel",
+    "None" : "Hiçbiri",
+    "Every day" : "Her gün",
+    "Every week" : "Her hafta",
+    "Every month" : "Her ay",
+    "Every year" : "Her yıl",
+    "never" : "hiçbir zaman",
+    "after" : "şundan sonra",
     "At time of event" : "Olay anında",
     "5 minutes before" : "5 dakika önce",
     "10 minutes before" : "10 dakika önce",
@@ -51,14 +39,14 @@ OC.L10N.register(
     "E Mail" : "E-posta",
     "Pop up" : "Açılır pencere",
     "sec" : "saniye",
-    "min" : "min",
+    "min" : "dk",
     "hours" : "saat",
     "days" : "gün",
     "week" : "hafta",
-    "Before" : "Önce",
-    "After" : "Sonra",
-    "Start" : "Başlat",
-    "End" : "Son",
+    "before" : "şundan önce",
+    "start" : "başlangıç",
+    "end" : "bitiş",
+    "Editing reminders of uknown type not supported." : "Bilinmeyen tür hatırlatıcılarının düzenlenmesi desteklenmiyor.",
     "Week {number} of {year}" : "{year} yılının {number}. haftası",
     "Successfully imported" : "Başarıyla içe aktarıldı",
     "Partially imported, 1 failure" : "Kısmen içe aktarıldı, 1 başarısız",
@@ -74,14 +62,30 @@ OC.L10N.register(
     "{type} at the event's end" : "Etkinlik bitiminde {type}",
     "{type} at {time}" : "{time} zamanında {type}",
     "{calendar} shared by {owner}" : "{owner} tarafından paylaşılmış {calendar}",
+    "Title of the Event" : "Etkinlik Başlığı",
+    "starts" : "başlangıç",
+    "ends" : "bitiş",
+    "All day Event" : "Tüm gün etkinliği",
+    "Location" : "Konum",
+    "Delete" : "Sil",
+    "Cancel" : "İptal",
+    "More ..." : "Daha fazla ...",
+    "Create" : "Oluştur",
+    "Update" : "Güncelle",
+    "Close" : "Kapat",
+    "Description" : "Açıklama",
+    "Export" : "Dışa aktar",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Üst yazılım hatası nedeniyle, takvim şu anda asset pipeline özelliğine destek veremiyor.",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Lütfen yöneticinizle iletişime geçip \"asset-pipeline.enabled\" yapılandırma seçeneğinin devre dışı bırakılmasını talep edin.",
     "Day" : "Gün",
     "Week" : "Hafta",
     "Month" : "Ay",
     "Today" : "Bugün",
     "Share Calendar" : "Takvimi Paylaş",
+    "More" : "Daha fazla",
+    "Edit" : "Düzenle",
     "group" : "grup",
     "New Calendar" : "Yeni Takvim",
-    "Create" : "Oluştur",
     "Subscriptions" : "Abonelikler",
     "New Subscription" : "Yeni Abonelik",
     "Url" : "Adres",
@@ -92,26 +96,21 @@ OC.L10N.register(
     "Type" : "Tür",
     "Relative" : "Bağıl",
     "Absolute" : "Kesin",
-    "Date" : "Tarih",
     "Repeat" : "Tekrarla",
     "times every" : "defa, her",
     "Add" : "Ekle",
-    "Title of the Event" : "Etkinlik Başlığı",
-    "from" : "kimden",
-    "to" : "alıcı",
-    "All day Event" : "Tüm gün etkinliği",
-    "Location" : "Konum",
-    "starts" : "başlangıç",
-    "ends" : "bitiş",
-    "Delete" : "Sil",
-    "Cancel" : "İptal",
-    "More ..." : "Daha fazla ...",
-    "Update" : "Güncelle",
-    "Close" : "Kapat",
-    "Interval" : "Aralık",
-    "Description" : "Açıklama",
-    "Export" : "Dışa aktar",
+    "E-Mail address of attendee" : "Katılımcının e-posta adresi",
+    "Please add your email address in the personal settings in order to add attendees." : "Lütfen katılımcıları eklemek için kişisel ayarlardan e-posta adresinizi ekleyin.",
+    "from" : "başlangıç",
+    "to" : "bitiş",
+    "This event's repeating rule is not supported yet." : "Bu etkinliğin tekrarlanma kuralı henüz desteklenmiyor.",
+    "Support for advanced rules will be added with subsequent updates." : "Gelişmiş kurallar sonraki güncellemelerde eklenecektir.",
+    "Reset repeating rule" : "Tekrarlama kuralını sıfırla",
+    "Repeat every ..." : "Tekrarlama koşulu...",
+    "end repeat ..." : "tekrarlama bitişi...",
+    "times" : "kez",
     "Import Calendars" : "Takimleri İçe Aktar",
+    "Import canceled" : "İçe aktarım iptal edildi",
     "Analyzing calendar" : "Takvim inceleniyor",
     "The file contains objects incompatible with the selected calendar" : "Dosya, seçili takvimle uyumsuz nesneler içeriyor",
     "New calendar" : "Yeni takvim",
