@@ -10,6 +10,7 @@ OC.L10N.register(
     "Required" : "必填",
     "Optional" : "选填",
     "Does not attend" : "不参加",
+    "Please create a calendar first." : "请先创建一个新的日历。",
     "New event" : "新事件",
     "Attendees" : "参加者",
     "Reminders" : "提醒",
@@ -17,8 +18,14 @@ OC.L10N.register(
     "When shared show full event" : "共享时显示完整事件",
     "When shared show only busy" : "共享时仅显示进行中的事件",
     "When shared hide this event" : "共享时隐藏本事件",
+    "Please add a title!" : "请添加一个标题。",
+    "Please select a calendar!" : "请选择一个日历。",
     "Global" : "全局",
     "None" : "不提醒",
+    "Every day" : "每天",
+    "Every week" : "每周",
+    "Every month" : "每月",
+    "Every year" : "每年",
     "never" : "从不",
     "At time of event" : "在事件发生的",
     "5 minutes before" : "5分钟前",
@@ -36,6 +43,8 @@ OC.L10N.register(
     "hours" : "小时",
     "days" : "天",
     "week" : "周",
+    "start" : "开始",
+    "end" : "结束",
     "Week {number} of {year}" : "{year}年的第{number}周",
     "Successfully imported" : "导入成功",
     "Partially imported, 1 failure" : "部分导入成功，1个失败",
@@ -88,7 +97,10 @@ OC.L10N.register(
     "Add" : "增加",
     "from" : "从",
     "to" : "到",
+    "Repeat every ..." : "重复",
+    "end repeat ..." : "结束重复",
     "Import Calendars" : "导入日历",
+    "Import canceled" : "导入已取消",
     "Analyzing calendar" : "分析日历",
     "The file contains objects incompatible with the selected calendar" : "该文件包含的内容与选择的日历不兼容",
     "New calendar" : "新建日历",
