@@ -10,6 +10,7 @@ OC.L10N.register(
     "Required" : "必填",
     "Optional" : "選填",
     "Does not attend" : "不參加",
+    "Please create a calendar first." : "請先建立一個日曆。",
     "New event" : "新活動",
     "Attendees" : "出席者",
     "Reminders" : "提醒",
@@ -35,7 +36,7 @@ OC.L10N.register(
     "2 hours before" : "2 小時前",
     "Custom" : "自訂",
     "Audio" : "音訊",
-    "E Mail" : "Email",
+    "E Mail" : "電子郵件",
     "Pop up" : "彈出視窗",
     "sec" : "秒",
     "min" : "分",
@@ -52,7 +53,7 @@ OC.L10N.register(
     "Partially imported, {n} failures" : "部分匯入，{n} 個失敗",
     "Audio alarm" : "聲音提醒",
     "Pop-up" : "彈出視窗",
-    "E-Mail" : "Email",
+    "E-Mail" : "電子郵件",
     "{type} {time} before the event starts" : "{type} 活動開始前 {time}",
     "{type} {time} before the event ends" : "{type} 活動結束前 {time}",
     "{type} {time} after the event starts" : "{type} 活動開始後 {time}",
