@@ -23,10 +23,13 @@
  */
 ?>
 <span class="calendarCheckbox" ng-show="!calendar.list.loading && !calendar.list.edit" ng-style="{ background : calendar.enabled == true ? calendar.color : 'transparent' }" ng-click="triggerEnable(calendar)"></span>
-<span class="loading pull-left" ng-show="calendar.list.loading && !calendar.list.edit">
-	<i class="fa fa-spinner fa-spin"></i>
-</span>
-<a href="#/" ng-click="triggerEnable(calendar)" ng-show="!calendar.list.edit" title="{{ calendar.displayname }}">
+<span class="icon-loading-small pull-left" ng-show="calendar.list.loading && !calendar.list.edit"></span>
+<a href="#" ng-click="triggerEnable(calendar)" ng-show="!calendar.list.edit" title="{{ calendar.displayname }}" class="action permanent">
+	<span
+		ng-if="calendar.hasWarnings()"
+		class="icon icon-error">
+		&nbsp;&nbsp;&nbsp;&nbsp;
+	</span>
 	{{ calendar.displayname }}
 </a>
 <span class="utils" ng-if="!calendar.list.locked" ng-show="!calendar.list.edit">
@@ -100,7 +103,7 @@
 		typeahead-on-select="onSelectSharee($item, $model, $label, calendar)"
 		typeahead-loading="loadingSharees"
 		ng-model="calendar.selectedSharee"
-		placeholder="Share with users or groups">
+		placeholder="<?php p($l->t('Share with users or groups')); ?>">
 	<ul class="calendar-share-list">
 		<li ng-repeat="userShare in calendar.sharedWith.users" class="calendar-share-item">
 			{{ userShare.displayname }} -
@@ -108,7 +111,7 @@
 				   id="checkbox_sharedWithUser_{{calendar.tmpId}}_{{$id}}"
 				   ng-model="userShare.writable" value="edit"
 				   ng-change="updateExistingUserShare(calendar, userShare.id, userShare.writable)">
-			<label for="checkbox_sharedWithUser_{{calendar.tmpId}}_{{$id}}"> can edit</label>
+			<label for="checkbox_sharedWithUser_{{calendar.tmpId}}_{{$id}}"> <?php p($l->t('can edit')); ?></label>
 			<span class="utils hide">
 				<span class="action">
 					<span href="#"
@@ -127,7 +130,7 @@
 				   id="checkbox_sharedWithGroup_{{calendar.tmpId}}_{{$id}}"
 				   ng-model="groupShare.writable" value="edit"
 				   ng-change="updateExistingGroupShare(calendar, groupShare.id, groupShare.writable)">
-			<label for="checkbox_sharedWithGroup_{{calendar.tmpId}}_{{$id}}"> can edit</label>
+			<label for="checkbox_sharedWithGroup_{{calendar.tmpId}}_{{$id}}"> <?php p($l->t('can edit')); ?></label>
 			<span class="utils hide">
 				<span class="action">
 					<span href="#"
